//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections;
using System.Drawing;
using System.Windows.Forms;


namespace MindFusion.Scheduling.WinForms.Samples.CS.MultipleGrouping
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			_appPath = System.IO.Path.GetDirectoryName(Application.ExecutablePath);

			_lbInfo.DocumentText = Properties.Resources.Info;
			_lbInfo.DocumentCompleted += new WebBrowserDocumentCompletedEventHandler(OnDocumentCompleted);

			calendar.Resources.Add(CreateResource<Resource>("Resource #1"));
			calendar.Resources.Add(CreateResource<Resource>("Resource #2"));
			calendar.Resources.Add(CreateResource<Resource>("Resource #3"));
			calendar.Resources.Add(CreateResource<Resource>("Resource #4"));

			calendar.Contacts.Add(CreateContact("Contact #1", "Contact #1"));
			calendar.Contacts.Add(CreateContact("Contact #2", "Contact #2"));
			calendar.Contacts.Add(CreateContact("Contact #3", "Contact #3"));
			calendar.Contacts.Add(CreateContact("Contact #4", "Contact #4"));

			calendar.Locations.Add(CreateResource<Location>("Location #1"));
			calendar.Locations.Add(CreateResource<Location>("Location #2"));
			calendar.Locations.Add(CreateResource<Location>("Location #3"));
			calendar.Locations.Add(CreateResource<Location>("Location #4"));

			calendar.Tasks.Add(CreateTask("Task #1"));
			calendar.Tasks.Add(CreateTask("Task #2"));
			calendar.Tasks.Add(CreateTask("Task #3"));
			calendar.Tasks.Add(CreateTask("Task #4"));
		}

		private void OnDocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
		{
			if (_lbInfo.Document != null)
			{
				_lbInfo.Document.Click += Document_Click;
				_lbInfo.Document.Body.Style = "font-family: Verdana, Arial, Helvetica, sans-serif; " +
					"font-size: 7.5pt; margin: 2pt; padding: 0pt; background-color: #ffffee; cursor: default;";
			}
		}

		/// <summary>
		/// Handles the Web browser document's Click event.
		/// </summary>
		private void Document_Click(object sender, HtmlElementEventArgs e)
		{
			e.ReturnValue = true;

			HtmlElement pointed = _lbInfo.Document.GetElementFromPoint(e.ClientMousePosition);
			if (pointed == null)
				return;

			if (pointed.TagName.ToLower() == "a")
			{
				string href = pointed.GetAttribute("href").ToLower();
				if (href.StartsWith("help:"))
				{
					string topic = href.Substring(5);
					string helpFile = ResolveHelpPath(_appPath);

					if (System.IO.File.Exists(helpFile))
					{
						Help.ShowHelp(this, helpFile, HelpNavigator.Topic, topic);

						// Prevent link follow
						e.ReturnValue = false;
					}
				}
			}
		}

		private static string ResolveHelpPath(string baseDir)
		{
			string[] helpFiles = new string[]
			{
				"MindFusion.Scheduling.chm",
				"MindFusion WinForms.chm"
			};

			System.IO.DirectoryInfo dirInfo = new System.IO.DirectoryInfo(baseDir);
			int i = 0;
			while (dirInfo != null)
			{
				string helpFile = System.IO.Path.Combine(dirInfo.FullName, helpFiles[i]);
				if (System.IO.File.Exists(helpFile))
					return helpFile;

				i++;
				if (i == helpFiles.Length)
				{
					i = 0;
					dirInfo = dirInfo.Parent;
				}
			}

			return string.Empty;
		}

		private void OnAbout(object sender, System.EventArgs e)
		{
			System.Reflection.Assembly assembly = System.Reflection.Assembly.GetAssembly(
				typeof(MindFusion.Scheduling.WinForms.Calendar));

			if (assembly == null)
				return;

			Type aboutFormType = assembly.GetType(
				"MindFusion.Scheduling.WinForms.AboutForm");

			if (aboutFormType == null)
				return;

			((Form)Activator.CreateInstance(aboutFormType)).ShowDialog(this);
		}

		private void OnExit(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private T CreateResource<T>(string name) where T : Resource, new()
		{
			T t = new T();
			t.Name = name;
			return t;
		}

		private Contact CreateContact(string name, string firstName)
		{
			Contact c = CreateResource<Contact>(name);
			c.FirstName = firstName;
			return c;
		}

		private Task CreateTask(string name)
		{
			Task t = CreateResource<Task>(name);
			t.Subject = name;
			return t;
		}

		private void groupby_CheckedChanged(object sender, EventArgs e)
		{
			groupBox2.Enabled = !groupby1None.Checked;

			if (groupby1None.Checked)
				calendar.GroupType = GroupType.None;
			else if (groupby1Contacts.Checked)
				calendar.GroupType = GroupType.GroupByContacts;
			else if (groupby1Locations.Checked)
				calendar.GroupType = GroupType.GroupByLocations;
			else if (groupby1Tasks.Checked)
				calendar.GroupType = GroupType.GroupByTasks;
			else if (groupby1Resources.Checked)
				calendar.GroupType = GroupType.GroupByResources;

			if (groupby2None.Checked)
				calendar.SecondaryGroupType = GroupType.None;
			else if (groupby2Contacts.Checked)
				calendar.SecondaryGroupType = GroupType.GroupByContacts;
			else if (groupby2Locations.Checked)
				calendar.SecondaryGroupType = GroupType.GroupByLocations;
			else if (groupby2Tasks.Checked)
				calendar.SecondaryGroupType = GroupType.GroupByTasks;
			else if (groupby2Resources.Checked)
				calendar.SecondaryGroupType = GroupType.GroupByResources;
		}


		private string _appPath;
	}
}
